%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MATLAB CODE FOR COMPILING A HIGHLY RESOLVED MRIO DATABASE: FINAL VERSION
% FOR THE PUBLICATION -> SUBMISSION (ADAPTED)
% 1) READ IN EXIOBASE AND EORA DATA AND IMPLEMENT ALL ENVIRONMENTAL AND
% SOCIO-ECONOMIC INDICATORS
% 2) RESOLVE ROW REGIONS OF EXIBOASE BY EORA
% 3) READ IN FAOSTAT DATA TO IMPROVE T AND Y MATRIX
% 4) READ IN DATA FROM PFISTER AND BAYER (2014) TO IMPROVE WATER STRESS DATA
% 5) READ IN DATA FROM PFISTER ET AL TO IMPROVE LAND-USE RELATED BIODIVERSITY LOSS DATA 
% 6) DERIVE FINAL MATRICES FOR RESOLVED DATABASE AND SAVE DATA AND LABELS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

for year = [1995:2015];
    year
    
    clearvars -except year
    
k_year = year-1994;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1A) READ IN EXIOBASE AND EORA DATA AND DERIVE T MATRIX FOR EXIOBASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Read in Labels and Data of Exiobase
datapath = ['Files/Exiobase/Labels/'];
load([datapath 'Labels_Production_Exio']);
load([datapath 'Labels_Regions_Exio']);
load([datapath 'Labels_Sectors_Exio']);
load([datapath 'Labels_FinalDemand_Exio']);
load([datapath 'Labels_FDcat_Exio']);
load([datapath 'Labels_Q_Exio']);

datapath = ['Files/Exiobase/IOT_' num2str(year) '_ixi/'];
A_Exio = dlmread([datapath 'A.txt'],'\t',3,2); % A = coefficient matrix with 7987 rows x 7987 columns (7987 = 163 sectors x 49 regions)
Y_Exio = dlmread([datapath 'Y.txt'],'\t',3,2); % Y = final demand with 7987 rows x 343 columns (343 = 49 regions x 7 final demand categories)
datapath = ['Files/Exiobase/IOT_' num2str(year) '_ixi/satellite/'];
Q_Exio = dlmread([datapath 'F.txt'],'\t',2,1); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)
Q_hh_Exio = dlmread([datapath 'F_hh.txt'],'\t',2,1); % Q_hh = environmental and social extensions (rows) for households (columns = 49 regions x 7 final demand categories)

% Leontief inverse for Exiobase
I_Exio = eye(size(A_Exio));
L_Exio = inv(I_Exio-A_Exio);

% Derive Total output of each region-sector combination to satisfy the global
% final demand (TotalOut)
X_Exio = L_Exio * Y_Exio;
TotalOut_Exio =sum(X_Exio,2);

% Derive T Matrix for Exiobase
T_Exio = A_Exio .* repmat(TotalOut_Exio',length(TotalOut_Exio'),1); 

% Read in Labels and Data of Eora
datapath = ['Files/Eora/Labels/'];
load([datapath 'Labels_Production_Eora'])
load([datapath 'Labels_Regions_Eora'])
load([datapath 'Labels_Sectors_Eora'])
load([datapath 'Labels_FinalDemand_Eora'])
load([datapath 'Labels_FDcat_Eora'])
load([datapath 'Labels_Q_Eora'])
load([datapath 'Labels_VA_Eora'])

datapath = ['Files/Eora/bp/Eora26_' num2str(year) '_bp/'];
T_Eora= importdata([datapath 'Eora26_' num2str(year) '_bp_T.txt']);
Y_Eora = importdata([datapath 'Eora26_' num2str(year) '_bp_FD.txt']);
VA_Eora = importdata([datapath 'Eora26_' num2str(year) '_bp_VA.txt']);
Q_Eora = importdata([datapath 'Eora26_' num2str(year) '_bp_Q.txt']);
Q_hh_Eora = importdata([datapath 'Eora26_' num2str(year) '_bp_QY.txt']);





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1B) DERIVE ENVIRONMENTAL AND SOCIO-ECONOMIC IMPACT CATEGORIES FOR EXIOBASE
% AND EORA
% 1. Material extraction (in kt)
% 2. Climate change impacts (in kg CO2eq)
% 3. PM health impacts (DALYs)
% 4. Water stress (Mio. m3 H2Oeq)
% 5. Land-use rel. biodiversity loss (global PDF)
% 6. Value added (Mio. Euro)
% 7. Workforce (1000 FTE)
% 8. Blue water consumption (Mio. m3 H2O)
% 9. Land-use (km2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%% 1. Material Footprint %%%%%%%%
% Calculate Material Footprint (MF) in kilotonnes: Exiobase
% extensions of the global economy
Ext_MF_Exio = sum(Q_Exio([471:687],:));  
% extensions of the households
Ext_hh_MF_Exio = sum(Q_hh_Exio([471:687],:));  %=0 for material extraction
% total global impacts
% E_total_global_MF_Exio = sum(Ext_MF_Exio) + sum(Ext_hh_MF_Exio);

% Calculate Material Footprint (MF) in kilotonnes: Eora
% extensions of the global economy
Ext_MF_Eora = Q_Eora(1868,:);
% Households
Ext_hh_MF_Eora = Q_hh_Eora([1868],:);
% total global impacts
% E_total_global_MF_Eora = sum(Ext_MF_Eora) + sum(Ext_hh_MF_Eora);



%%%%%%%%  2. Climate Change Impacts %%%%%%%% 
% Calculate Climate Change Impacts (CC) in kg CO2 equivalents: Exiobase
% Define CFs
CF_CH4 = 28;
CF_N2O = 265;
% extensions of the global economy
Ext_CC_Exio = sum(Q_Exio([24,93,94,428,438,439],:)) + sum(Q_Exio([25,68:75,427,436],:)) .* CF_CH4 + sum(Q_Exio([26,430],:)) .* CF_N2O + Q_Exio(425,:) + Q_Exio(426,:);
% extensions of the households
Ext_hh_CC_Exio = sum(Q_hh_Exio([24,93,94,428,438,439],:)) + sum(Q_hh_Exio([25,68:75,427,436],:)) .* CF_CH4 + sum(Q_hh_Exio([26,430],:)) .* CF_N2O + Q_hh_Exio(425,:) + Q_hh_Exio(426,:);
% total global impacts
% E_total_global_CC_Exio = sum(Ext_CC_Exio) + sum(Ext_hh_CC_Exio);

% Calculate Climate Change Impacts (CC) in kg CO2 equivalents: Eora
Ext_CC_Eora = (Q_Eora([2709],:) + Q_Eora([2503],:) .* CF_CH4 + Q_Eora([2639],:) .* CF_N2O + Q_Eora([2571],:) + Q_Eora([2656],:)) .* 1000000;
Ext_hh_CC_Eora =  (sum(Q_hh_Eora([10:48,51,57:64],:)) + sum(Q_hh_Eora([120:158,161,167:174],:)) .* CF_CH4 + sum(Q_hh_Eora([175:213,216,222:229],:)) .* CF_N2O) .* 1000000;
% total global impacts
% E_total_global_CC_Eora = sum(Ext_CC_Eora) + sum(Ext_hh_CC_Eora);



%%%%%%%% 3. PM health impacts %%%%%%%%
% Calculate PM Health Impacts (HI) in DALYs: Exiobase
% PM2.5, NOx, SOx and NH3 emissions reported by the satellite matrix of EXIOBASE 3.4 
% are weighted with sector specific characterization factors adapted from the UNEP-SETAC method.
% for extracting sectors we assume outdoor rural emissions (with ground-level emissions for PM2.5)
% for processing sectors we assume the average of outdoor rural and outdoor urban emissions
% for the remaining economy we assume the average of outdoor urban emissions

% define sector index
mining_Exio = 1:34;
processing_Exio = [35:43, 51:53, 56:63, 65:84, 122];
other_Exio = [44:50, 54:55, 64, 85:121, 123:163];

% CFs for PM25
CF_PM25_mining_Exio = 0.0002320757; 
CF_PM25_processing_Exio = 0.0011171740; 
CF_PM25_other_Exio = 0.0021326226; 
for i = mining_Exio;
for n = 0:48;
    j = i + 163*n;
CF_PM25_Exio(j) = CF_PM25_mining_Exio; 
end
end
for i = processing_Exio;
for n = 0:48;
    j = i + 163*n;
CF_PM25_Exio(j) = CF_PM25_processing_Exio;
end
end
for i = other_Exio;
for n = 0:48;
    j = i + 163*n;
CF_PM25_Exio(j) = CF_PM25_other_Exio ;
end
end

% CFs for SOx
CF_SOx_mining_Exio = 0.0000190000;
CF_SOx_processing_Exio = 0.0000845000;
CF_SOx_other_Exio = 0.0001500000;
for i = mining_Exio;
for n = 0:48;
    j = i + 163*n;
CF_SOx_Exio(j) = CF_SOx_mining_Exio ;
end
end
for i = processing_Exio;
for n = 0:48;
    j = i + 163*n;
CF_SOx_Exio(j) = CF_SOx_processing_Exio ;
end
end
for i = other_Exio;
for n = 0:48;
    j = i + 163*n;
CF_SOx_Exio(j) = CF_SOx_other_Exio ;
end
end

% CFs for NOx
CF_NOx_mining_Exio = 0.0000040000;
CF_NOx_processing_Exio = 0.0000175000;
CF_NOx_other_Exio = 0.0000310000;
for i = mining_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NOx_Exio(j) = CF_NOx_mining_Exio ;
end
end
for i = processing_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NOx_Exio(j) = CF_NOx_processing_Exio;
end
end
for i = other_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NOx_Exio(j) = CF_NOx_other_Exio;
end
end

% CFs for NH3
CF_NH3_mining_Exio = 0.0000400000;
CF_NH3_processing_Exio = 0.0001500000;
CF_NH3_other_Exio = 0.0002600000;
for i = mining_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NH3_Exio(j) = CF_NH3_mining_Exio;
end
end
for i = processing_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NH3_Exio(j) = CF_NH3_processing_Exio;
end
end
for i = other_Exio;
for n = 0:48;
    j = i + 163*n;
CF_NH3_Exio(j) = CF_NH3_other_Exio;
end
end

% extensions of the economy
Ext_HI_Exio = sum(Q_Exio([40,283:328,445],:)) .* CF_PM25_Exio + sum(Q_Exio([27,343:361,446],:)) .* CF_SOx_Exio + sum(Q_Exio([28,189:210,432,443],:)) .* CF_NOx_Exio + sum(Q_Exio([29,141,431,442],:)) .* CF_NH3_Exio ;

% extensions of the households
Ext_hh_HI_Exio = sum(Q_hh_Exio([40,283:328,445],:)) .* CF_PM25_other_Exio + sum(Q_hh_Exio([27,343:361,446],:)) .* CF_SOx_other_Exio + sum(Q_hh_Exio([28,189:210,432,443],:)) .* CF_NOx_other_Exio + sum(Q_hh_Exio([29,141,431,442],:)) .* CF_NH3_other_Exio;


% HEALTH IMPACTS [DALYs] ? Eora
% Define CFs for mining, processing and remaining economy separately
mining = 1:3;
processing = [5:8];
other = [9:26];

CF_PM25_mining = 0.0002320757;
CF_PM25_processing = 0.0011171740;
CF_PM25_other = 0.0021326226;
for i = mining;
for n = 0:188;
    j = i + 26*n;
CF_PM25(j) = CF_PM25_mining ;
end
end
for i = processing;
for n = 0:188;
    j = i + 26*n;
CF_PM25(j) = CF_PM25_processing ;
end
end
for i = other;
for n = 0:188;
    j = i + 26*n;
CF_PM25(j) = CF_PM25_other ;
end
end
CF_PM25(4915) = CF_PM25_other ;

CF_SOx_mining = 0.0000190000;
CF_SOx_processing = 0.0000845000;
CF_SOx_other = 0.0001500000;
for i = mining;
for n = 0:188;
    j = i + 26*n;
CF_SOx(j) = CF_SOx_mining ;
end
end
for i = processing;
for n = 0:188;
    j = i + 26*n;
CF_SOx(j) = CF_SOx_processing ;
end
end
for i = other;
for n = 0:188;
    j = i + 26*n;
CF_SOx(j) = CF_SOx_other ;
end
end
CF_SOx(4915) = CF_SOx_other ;

CF_NOx_mining = 0.0000040000;
CF_NOx_processing = 0.0000175000;
CF_NOx_other = 0.0000310000;
for i = mining;
for n = 0:188;
    j = i + 26*n;
CF_NOx(j) = CF_NOx_mining ;
end
end
for i = processing;
for n = 0:188;
    j = i + 26*n;
CF_NOx(j) = CF_NOx_processing ;
end
end
for i = other;
for n = 0:188;
    j = i + 26*n;
CF_NOx(j) = CF_NOx_other ;
end
end
CF_NOx(4915) = CF_NOx_other ;

CF_NH3_mining = 0.0000400000;
CF_NH3_processing = 0.0001500000;
CF_NH3_other = 0.0002600000;
for i = mining;
for n = 0:188;
    j = i + 26*n;
CF_NH3(j) = CF_NH3_mining ;
end
end
for i = processing;
for n = 0:188;
    j = i + 26*n;
CF_NH3(j) = CF_NH3_processing ;
end
end
for i = other;
for n = 0:188;
    j = i + 26*n;
CF_NH3(j) = CF_NH3_other ;
end
end
CF_NH3(4915) = CF_NH3_other ;

conversion_PM25 = 3.48384;

% Select here if you want to calculate total health impacts
Ext_HI_Eora = ((sum(Q_Eora([1664:1703,1705,1711:1718],:)) ./ conversion_PM25) .* CF_PM25 + sum(Q_Eora([1609:1648,1650,1656:1663],:)) .* CF_SOx + sum(Q_Eora([1444:1483,1584,1491:1498],:)) .* CF_NOx + sum(Q_Eora([1554:1593,1595,1601:1608],:)) .* CF_NH3) .* 1000000; 

% Household Emissions von jeder Region
Ext_hh_HI_Eora = ((sum(Q_hh_Eora([1664:1703,1705,1711:1718],:)) ./ conversion_PM25) .* CF_PM25_other + sum(Q_hh_Eora([1609:1648,1650,1656:1663],:)) .* CF_SOx_other + sum(Q_hh_Eora([1444:1483,1584,1491:1498],:)) .* CF_NOx_other + sum(Q_hh_Eora([1554:1593,1595,1601:1608],:)) .* CF_NH3_other) .* 1000000;




%%%%%%%% 4. Water stress %%%%%%%%
% Calculate Water Stress (WS) in Mio m3 H2O equivalents: Exiobase
% Water consumption reported by the satellite matrix of EXIOBASE 3.4 was weighted 
% with sector-region specific impact factors to derive water stress.
datapath = ['Files/Exiobase/CF/'];
CF_water_Exio = dlmread([datapath 'CF_water_exio.txt'],'\t',2,2); % impact factors to derive water stress

%Define CFs for region-sector comb.
index_CF_water_Exio = [1,2,3,4,5,6,7,8,repmat(9,1,11),repmat(10,1,144)]; % assign the impact factors to the respective sectors
n = 0;
for i = 1:49
for j = index_CF_water_Exio   
n = n+1;    
CF_water_rs_Exio(n) = CF_water_Exio(i,j);
end
end

%Define CFs for households
n = 0;
for i = 1:49
for j =  repmat(10,1,7)
n = n+1;    
CF_water_hh_Exio(n) = CF_water_Exio(i,j);
end
end

% extensions of the economy
Ext_Exio = sum(Q_Exio([924:1026],:));
Ext_WS_Exio = CF_water_rs_Exio .* Ext_Exio;

% extensions of the households
Ext_hh_WS_Exio_int = sum(Q_hh_Exio([924:1026],:)); 
Ext_hh_WS_Exio = CF_water_hh_Exio .* Ext_hh_WS_Exio_int;


% Water stress: Eora
%AGRI CF definieren fr region-sector comb.
datapath = ['Files/Eora/CFs/'];
CF_water_Eora = dlmread([datapath 'CF_water_eora.txt'],'\t',1,1);
n = 0;
for i = 1:189
for j = repmat(1,1,26)   
n = n+1;    
CF_water_ag_Eora(n) = CF_water_Eora(i,j);
end
end
CF_water_ag_Eora(4915) = CF_water_Eora(190,1);
%Non AGRI CF definieren fr region-sector comb.
n = 0;
for i = 1:189
for j =  repmat(2,1,26)
n = n+1;    
CF_water_non_Eora(n) = CF_water_Eora(i,j);
end
end
CF_water_non_Eora(4915) = CF_water_Eora(190,2);

% extensions 
Ext_WS_Eora = sum(Q_Eora([2486,2489],:)) .* CF_water_ag_Eora + sum(Q_Eora([2492,2495,2498],:)) .* CF_water_non_Eora;

%Non AGRI CF definieren fr households
n = 0;
for i = 1:190
for j =  repmat(2,1,6)
n = n+1;    
CF_water_hh_Eora(n) = CF_water_Eora(i,j);
end
end

% Household Emissions von jeder Region
Ext_hh_WS_Eora = sum(Q_hh_Eora([2486,2489,2492,2495,2498],:)) .* CF_water_hh_Eora;




%%%%%%%% 5. Land-use rel. biodiversity loss %%%%%%%%
% Calculate Land-use related Biodiversity Loss (LU) in global PDF: Exiobase
% Read in data to derive CFs for land-use related-biodiversity loss
datapath = ['Files/Exiobase/CF/'];
CF_landuse_Exio = dlmread([datapath 'CF_landuse_exio.txt'],'\t',2,2);
CF_landuse_Exio(:, 11) = 0; % to set "other land use" = 0
Q_2007_Exio = dlmread([datapath 'F_2007_exio.txt'],'\t',2,1);
Q_2007_hh_Exio = dlmread([datapath 'F_hh_2007_exio.txt'],'\t',2,1);

% Derive CFs for the economy
% Extensions of the year 2007 (necessary to derive CFs)
Ext_2007_Exio(1,:) = Q_2007_Exio(447,:); %cereal grains nec
Ext_2007_Exio(2,:) = Q_2007_Exio(448,:); %crops nec
Ext_2007_Exio(3,:) = sum(Q_2007_Exio(449:453,:)); % sum of fodder crops
Ext_2007_Exio(4,:) = Q_2007_Exio(454,:); % oil seeds
Ext_2007_Exio(5,:) = Q_2007_Exio(455,:); % paddy rice
Ext_2007_Exio(6,:) = Q_2007_Exio(456,:); % plant-based fibers
Ext_2007_Exio(7,:) = Q_2007_Exio(457,:); % sugar cane & sugar beet
Ext_2007_Exio(8,:) = Q_2007_Exio(458,:); % vegetables, fruits, nuts
Ext_2007_Exio(9,:) = Q_2007_Exio(459,:); % wheat
Ext_2007_Exio(10,:) = Q_2007_Exio(460,:); % forestry
Ext_2007_Exio(11,:) = Q_2007_Exio(461,:); % other land use (=0)
Ext_2007_Exio(12,:) = sum(Q_2007_Exio(462:464,:)); % permanent pastures
Ext_2007_Exio(13,:) = Q_2007_Exio(465,:); % infrastructure land
Ext_2007_Exio(14,:) = Q_2007_Exio(466,:); % forest area marginal use

% Extensions of the chosen year
Ext_year_Exio(1,:) = Q_Exio(447,:); % same description as for 2007
Ext_year_Exio(2,:) = Q_Exio(448,:);
Ext_year_Exio(3,:) = sum(Q_Exio(449:453,:));
Ext_year_Exio(4,:) = Q_Exio(454,:);
Ext_year_Exio(5,:) = Q_Exio(455,:);
Ext_year_Exio(6,:) = Q_Exio(456,:);
Ext_year_Exio(7,:) = Q_Exio(457,:);
Ext_year_Exio(8,:) = Q_Exio(458,:);
Ext_year_Exio(9,:) = Q_Exio(459,:);
Ext_year_Exio(10,:) = Q_Exio(460,:);
Ext_year_Exio(11,:) = Q_Exio(461,:);
Ext_year_Exio(12,:) = sum(Q_Exio(462:464,:));
Ext_year_Exio(13,:) = Q_Exio(465,:);
Ext_year_Exio(14,:) = Q_Exio(466,:);

for q = 1:14;
for n = 0:48;
i = 1 + 163*n;
j = i + 162;
z = n+1;
CF_landuse_e_Exio(q,i:j) = CF_landuse_Exio(z,q);
end
end

for q = 1:9
for n = 0:48;
    i = 1 + 163*n;
    j = i + 162;
for z =  i:j;  
    if Ext_2007_Exio(q,z)>0
        CF_landuse_final_Exio(q,z)= CF_landuse_e_Exio(q,z) / sum(sum(Ext_2007_Exio(q,i:j)));
    else
        CF_landuse_final_Exio(q,z)= 0;  
    end
end
end
end

CF_landuse_final_Exio(10:14,:) = CF_landuse_e_Exio(10:14,:)*10^6;
Ext_LU_Exio =  sum(CF_landuse_final_Exio .* Ext_year_Exio);

% Derive CFs for households
Ext_2007_hh_Exio(1,:) = Q_2007_hh_Exio(447,:);
Ext_2007_hh_Exio(2,:) = Q_2007_hh_Exio(448,:);
Ext_2007_hh_Exio(3,:) = sum(Q_2007_hh_Exio(449:453,:));
Ext_2007_hh_Exio(4,:) = Q_2007_hh_Exio(454,:);
Ext_2007_hh_Exio(5,:) = Q_2007_hh_Exio(455,:);
Ext_2007_hh_Exio(6,:) = Q_2007_hh_Exio(456,:);
Ext_2007_hh_Exio(7,:) = Q_2007_hh_Exio(457,:);
Ext_2007_hh_Exio(8,:) = Q_2007_hh_Exio(458,:);
Ext_2007_hh_Exio(9,:) = Q_2007_hh_Exio(459,:);
Ext_2007_hh_Exio(10,:) = Q_2007_hh_Exio(460,:);
Ext_2007_hh_Exio(11,:) = Q_2007_hh_Exio(461,:);
Ext_2007_hh_Exio(12,:) = sum(Q_2007_hh_Exio(462:464,:));
Ext_2007_hh_Exio(13,:) = Q_2007_hh_Exio(465,:);
Ext_2007_hh_Exio(14,:) = Q_2007_hh_Exio(466,:);

Ext_year_hh_Exio(1,:) = Q_hh_Exio(447,:);
Ext_year_hh_Exio(2,:) = Q_hh_Exio(448,:);
Ext_year_hh_Exio(3,:) = sum(Q_hh_Exio(449:453,:));
Ext_year_hh_Exio(4,:) = Q_hh_Exio(454,:);
Ext_year_hh_Exio(5,:) = Q_hh_Exio(455,:);
Ext_year_hh_Exio(6,:) = Q_hh_Exio(456,:);
Ext_year_hh_Exio(7,:) = Q_hh_Exio(457,:);
Ext_year_hh_Exio(8,:) = Q_hh_Exio(458,:);
Ext_year_hh_Exio(9,:) = Q_hh_Exio(459,:);
Ext_year_hh_Exio(10,:) = Q_hh_Exio(460,:);
Ext_year_hh_Exio(11,:) = Q_hh_Exio(461,:);
Ext_year_hh_Exio(12,:) = sum(Q_hh_Exio(462:464,:));
Ext_year_hh_Exio(13,:) = Q_hh_Exio(465,:);
Ext_year_hh_Exio(14,:) = Q_hh_Exio(466,:);

for q = 1:14;
for n = 0:48;
i = 1 + 7*n;
j = i + 6;
z = n+1;
CF_landuse_hh_Exio(q,i:j) = CF_landuse_Exio(z,q);
end
end

for q = 1:9
for n = 0:48;
    i = 1 + 7*n;
    j = i + 6;
for z =  i:j;  
    if Ext_2007_hh_Exio(q,z)>0
        CF_landuse_final_hh_Exio(q,z)= CF_landuse_hh_Exio(q,z) / sum(sum(Ext_2007_hh_Exio(q,i:j)));
    else
        CF_landuse_final_hh_Exio(q,z)= 0;  
    end
end
end
end
CF_landuse_final_hh_Exio(10:14,:) = CF_landuse_hh_Exio(10:14,:)*10^6;

Ext_hh_LU_Exio =  sum(CF_landuse_final_hh_Exio .* Ext_year_hh_Exio);


% Land-use related biodiversity loss for Eora
datapath = ['Files/Eora/CFs/'];
CF_landuse_Eora = dlmread([datapath 'CF_landuse_eora.txt'],'\t',1,1);
forestry_Eora = dlmread([datapath 'forestry_eora.txt'],'\t',1,1);
infrastructure_Eora = dlmread([datapath 'infrastructure_land_km2_eora.txt'],'\t',1,1);

% index for year
k_year = year-1994;

Ext_LUA_Eora(1,:) = Q_Eora(2424,:) / 100; % Cropland in ha --> /100 to convert in km2
Ext_LUA_Eora(2,:) = Q_Eora(2461,:) * 10 ; % Pastures in 1000 ha --> * 10 to convert in km2

% land-use related biodiversity loss
Ext_LU_Eora_int = zeros(3,4915);

% CFs for permanent crops and pastures
CF_landuse_e_Eora = zeros(2,4915);
q2 = 0;
for q = [1,3]
    q2 = q2 + 1;
for n = 1:189;
i = 1 + 26*(n-1);
j = i + 25;
CF_landuse_e_Eora(q2,i:j) = CF_landuse_Eora(n,q);
end
end

Ext_LU_Eora_int(1:2,:) = Ext_LUA_Eora .* 10^6 .* CF_landuse_e_Eora;

Ext_forestry_countrylevel = (forestry_Eora(:,k_year) * 10^7) .* CF_landuse_Eora(1:189,4);
% multiply with * 10 to transform 1000 ha in 1 km & multiply with 10^6 to transform into m2
% I use mean forestry CFs (4th column of CF_land-use_Eora)

for r = 1:189
    i = 1 + (r-1)*26;
    Ext_LU_Eora_int(3,i) = Ext_forestry_countrylevel(r);
end

Ext_LU_Eora = sum(Ext_LU_Eora_int,1);

% Households: infrastructure land
Ext_hh_infrastructure_countrylevel = (infrastructure_Eora(:,k_year) * 10^6) .* CF_landuse_Eora(1:189,5);
% multiply with 10^6 to transform km2 into m2
% I use mean urban CFs (5th column of CF_land-use_Eora)

Ext_hh_LU_Eora = zeros(1,1140);

for r = 1:189
    i = 1 + (r-1)*6;
    Ext_hh_LU_Eora(1,i) = Ext_hh_infrastructure_countrylevel(r);
end


%%%%%%%% 6. Value Added %%%%%%%%
% is calculated as a residual from the resolved total output and the column
% sum of the resolved T matrix to balance the database at the end (section 6A)


%%%%%%%% 7. Workforce %%%%%%%%
% only indicated by Exiobase
Ext_WF_Exio = sum(Q_Exio([10:15,22],:));


%%%%%%%% 8. Blue water consumption %%%%%%%%
% Exiobase
% extensions of the economy
Ext_BWC_Exio = sum(Q_Exio([924:1026],:));
% extensions of the households
Ext_hh_BWC_Exio = sum(Q_hh_Exio([924:1026],:));

% Eora
% extensions of the economy
Ext_BWC_Eora = sum(Q_Eora([2486,2489,2492,2495,2498],:));
% extensions of the households
Ext_hh_BWC_Eora = sum(Q_hh_Eora([2486,2489,2492,2495,2498],:));



%%%%%%%% 9. Land-use %%%%%%%%
%Exiobase
Ext_LUA_Exio = sum(Ext_year_Exio([1:10,12:14],:)); %neglect other land use
Ext_hh_LUA_Exio = sum(Ext_year_hh_Exio([1:10,12:14],:)); %neglect other land use

% Eora
clear Ext_LUA_Eora

Ext_LUA_Eora = zeros(3,4915);
Ext_LUA_Eora(1,:) = Q_Eora(2424,:) / 100; % Cropland in ha --> /100 to convert in km2
Ext_LUA_Eora(2,:) = Q_Eora(2461,:) * 10 ; % Pastures in 1000 ha --> * 10 to convert in km2
for r = 1:189
    i = 1 + (r-1)*26;
    Ext_LUA_Eora(3,i) = forestry_Eora(r,k_year) *10; % forestry in 1000 ha --> * 10 to convert in km2
end

Ext_LUA_Eora = sum(Ext_LUA_Eora);

Ext_hh_LUA_Eora = zeros(1,1140);

for r = 1:189
    i = 1 + (r-1)*6;
    Ext_hh_LUA_Eora(1,i) = infrastructure_Eora(r,k_year);
end







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1C) DEFINE MATCH BETWEEN EXIOBASE ROW REGIONS AND EORA COUNTRIES
%     & MATCH BETWEEN EXIOBASE SECTORS AND EORA SECTORS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SECTOR CONVERSION
Eora_Sector_1 = [1:18];
Eora_Sector_2 = [19];
Eora_Sector_3 = [20:34];
Eora_Sector_4 = [35:45];
Eora_Sector_5 = [47:49];
Eora_Sector_6 = [50:54];
Eora_Sector_7 = [56,57,59:63,65:71,122];
Eora_Sector_8 = [58,72:84];
Eora_Sector_9 = [86:90];
Eora_Sector_10 = [91:92];
Eora_Sector_11 = [46,64,85,93];
Eora_Sector_12 = [94,95];
Eora_Sector_13 = [96:112];
Eora_Sector_14 = [113,114];
Eora_Sector_15 = [115,118];
Eora_Sector_16 = [117];
Eora_Sector_17 = [116];
Eora_Sector_18 = [119];
Eora_Sector_19 = [120,121,123:126];
Eora_Sector_20 = [127];
Eora_Sector_21 = [128:132,135];
Eora_Sector_22 = [136];
Eora_Sector_23 = [55,133,134,137,138,159,160,161,163];
Eora_Sector_24 = [162];
Eora_Sector_25 = [139:158];
%Eora_Sector_26 = [];

Eora_Exio_Sector(1,1) = num2cell(Eora_Sector_1',1);
Eora_Exio_Sector(2,1) = num2cell(Eora_Sector_2',1);
Eora_Exio_Sector(3,1) = num2cell(Eora_Sector_3',1);
Eora_Exio_Sector(4,1) = num2cell(Eora_Sector_4',1);
Eora_Exio_Sector(5,1) = num2cell(Eora_Sector_5',1);
Eora_Exio_Sector(6,1) = num2cell(Eora_Sector_6',1);
Eora_Exio_Sector(7,1) = num2cell(Eora_Sector_7',1);
Eora_Exio_Sector(8,1) = num2cell(Eora_Sector_8',1);
Eora_Exio_Sector(9,1) = num2cell(Eora_Sector_9',1);
Eora_Exio_Sector(10,1) = num2cell(Eora_Sector_10',1);
Eora_Exio_Sector(11,1) = num2cell(Eora_Sector_11',1);
Eora_Exio_Sector(12,1) = num2cell(Eora_Sector_12',1);
Eora_Exio_Sector(13,1) = num2cell(Eora_Sector_13',1);
Eora_Exio_Sector(14,1) = num2cell(Eora_Sector_14',1);
Eora_Exio_Sector(15,1) = num2cell(Eora_Sector_15',1);
Eora_Exio_Sector(16,1) = num2cell(Eora_Sector_16',1);
Eora_Exio_Sector(17,1) = num2cell(Eora_Sector_17',1);
Eora_Exio_Sector(18,1) = num2cell(Eora_Sector_18',1);
Eora_Exio_Sector(19,1) = num2cell(Eora_Sector_19',1);
Eora_Exio_Sector(20,1) = num2cell(Eora_Sector_20',1);
Eora_Exio_Sector(21,1) = num2cell(Eora_Sector_21',1);
Eora_Exio_Sector(22,1) = num2cell(Eora_Sector_22',1);
Eora_Exio_Sector(23,1) = num2cell(Eora_Sector_23',1);
Eora_Exio_Sector(24,1) = num2cell(Eora_Sector_24',1);
Eora_Exio_Sector(25,1) = num2cell(Eora_Sector_25',1);
%Eora_Exio_Sector(26,1) = num2cell(Eora_Sector_26',1);


% REGION CONVERSION
countries = [11,18,29,46,47,67,51,58,158,61,62,69,44,77,83,85,100,101,94,108,120,136,137,141,163,154,153,179,181,87,40,34,139,26,79,111,142,10,164,173,166,127,80,156];

RoW_AsiaPacific = [1,8,12,15,22,28,32,49,60,63,66,76,89,92,93,102,105,106,113,117,119,122,123,130,132,135,144,152,159,167,168,174,183,184,186];
RoW_America = [6,7,9,13,16,19,21,23,27,36,39,41,43,45,54,56,70,71,73,74,75,86,121,124,131,133,134,161,171,182,185];
RoW_Europe = [2,4,17,24,78,99,112,114,140,145,149,169,177];
RoW_Africa = [3,5,20,25,30,31,33,35,37,38,42,48,50,52,53,57,59,64,65,68,72,90,96,97,98,103,104,107,109,110,115,116,118,125,126,143,146,148,150,151,155,157,160,162,170,172,176,180,188,189];
RoW_MiddleEast = [14,55,81,82,84,88,91,95,128,129,138,147,165,175,178,187];

k = 0;
for i = countries
    k = k+1;
Exio_Eora_Region(k,1) = num2cell(i);
end

Exio_Eora_Region(45,1) = num2cell(RoW_AsiaPacific',1);
Exio_Eora_Region(46,1) = num2cell(RoW_America',1);
Exio_Eora_Region(47,1) = num2cell(RoW_Europe',1);
Exio_Eora_Region(48,1) = num2cell(RoW_Africa',1);
Exio_Eora_Region(49,1) = num2cell(RoW_MiddleEast',1);













%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2) DISAGGREGATION OF EXIOBASE ACC. TO EORA FOR ALL ROW REGIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%% 1. T Matrix %%%%%%%% 
   null_T = 0;
    i = 0;
    for o_r_exio = 1:49;
        o_r_exio
    o_r_eora_total = cell2mat(Exio_Eora_Region(o_r_exio))';  
    for o_r_eora_single = o_r_eora_total;
    for o_s_eora = 1:25;   
    o_s_exio_total = cell2mat(Eora_Exio_Sector(o_s_eora))';    
    for o_s_exio_single = o_s_exio_total;
    i = i + 1;   
    o_r_s_exio =  (o_r_exio-1) * 163  + o_s_exio_single;
    o_r_s_eora_single = (o_r_eora_single - 1) * 26  + o_s_eora; 
    o_r_s_eora_total =  (o_r_eora_total - 1) * 26 + o_s_eora;   
    k = 0;
    for p_r_exio = 1:49       % each RoW Region  
    p_r_eora_total = cell2mat(Exio_Eora_Region(p_r_exio))'; % corresponding index for each RoW Region in Eora 
    for p_r_eora_single = p_r_eora_total % corresponding index for each single RoW country in Eora 
    for p_s_eora = 1:25
    p_s_exio_total = cell2mat(Eora_Exio_Sector(p_s_eora))';
    for p_s_exio_single = p_s_exio_total;
    k = k+1;               % index of the sector-countries in prod persp. for final matrix
    p_r_s_exio = (p_r_exio-1) * 163  + p_s_exio_single;  % index of the sector-RoWregion in prod persp. for exio
    p_r_s_eora_single = (p_r_eora_single - 1) * 26  + p_s_eora; % index of the sector-RoWcountry in prod persp. for eora
    p_r_s_eora_total = (p_r_eora_total - 1) * 26 + p_s_eora; % index of the sector-RoWregion in prod persp. for eora (vector)
    if (o_r_exio < 45) && (p_r_exio < 45)
    T_Exio_res(k,i) = T_Exio(p_r_s_exio,o_r_s_exio);    
    else
    if sum(sum(T_Eora(p_r_s_eora_total,o_r_s_eora_total))) > 0
    T_Exio_res(k,i) = T_Exio(p_r_s_exio,o_r_s_exio) * T_Eora(p_r_s_eora_single,o_r_s_eora_single) / sum(sum(T_Eora(p_r_s_eora_total,o_r_s_eora_total)));
    else
    null_T = null_T + 1;    
    T_Exio_res(k,i) = 0;
    end
    end
    end
    end
    end
    end
    end
    end
    end
    end



%%%%%%%% 2. Y Matrix %%%%%%%% 
p = 0;
q = 0;
for n = 0:48;
i = 1 + 7*n;
j = i + 5;
q = p + 1;
p = q + 5;
Y_Exio_1(:,q:p) = Y_Exio(:,i:j);
end
    
 null_Y = 0;
    i = 0;
    for o_r_exio = 1:49;
    o_r_eora_total = cell2mat(Exio_Eora_Region(o_r_exio))';  
    for o_r_eora_single = o_r_eora_total;
    for o_c_both = 1:6;   
    i = i + 1;   
    o_r_c_exio =  (o_r_exio-1) * 6  + o_c_both;
    o_r_c_eora_single = (o_r_eora_single - 1) * 6  + o_c_both; 
    o_r_c_eora_total =  (o_r_eora_total - 1) * 6 + o_c_both;   
    k = 0;
    for p_r_exio = 1:49       % each RoW Region  
    p_r_eora_total = cell2mat(Exio_Eora_Region(p_r_exio))'; % corresponding index for each RoW Region in Eora 
    for p_r_eora_single = p_r_eora_total % corresponding index for each single RoW country in Eora 
    for p_s_eora = 1:25;      
    p_s_exio_total = cell2mat(Eora_Exio_Sector(p_s_eora))';
    for p_s_exio_single = p_s_exio_total;
    k = k+1;               % index of the sector-countries in prod persp. for final matrix
    p_r_s_exio = (p_r_exio-1) * 163  + p_s_exio_single;  % index of the sector-RoWregion in prod persp. for exio
    p_r_s_eora_single = (p_r_eora_single - 1) * 26  + p_s_eora; % index of the sector-RoWcountry in prod persp. for eora
    p_r_s_eora_total = (p_r_eora_total - 1) * 26 + p_s_eora; % index of the sector-RoWregion in prod persp. for eora (vector)
    if (o_r_exio < 45) && (p_r_exio < 45)
    Y_Exio_res(k,i) = Y_Exio_1(p_r_s_exio,o_r_c_exio);    
    else    
    if sum(sum(Y_Eora(p_r_s_eora_total,o_r_c_eora_total))) > 0
    Y_Exio_res(k,i) = Y_Exio_1(p_r_s_exio,o_r_c_exio) * Y_Eora(p_r_s_eora_single,o_r_c_eora_single) / sum(sum(Y_Eora(p_r_s_eora_total,o_r_c_eora_total)));
    else
    null_Y = null_Y + 1;    
    Y_Exio_res(k,i) = 0;
    end
    end
    end
    end
    end
    end
    end
    end
    end
    



%%%%%%%% 3. Extensions of the economy %%%%%%%% 
 k = 0;
    for p_r_exio = 1:49       % each RoW Region  
    p_r_eora_total = cell2mat(Exio_Eora_Region(p_r_exio))'; % corresponding index for each RoW Region in Eora 
    for p_r_eora_single = p_r_eora_total % corresponding index for each single RoW country in Eora 
    for p_s_eora = 1:25;      
    p_s_exio_total = cell2mat(Eora_Exio_Sector(p_s_eora))';
    for p_s_exio_single = p_s_exio_total;
    k = k+1 ;              % index of the sector-countries in prod persp. for final matrix
    p_r_s_exio = (p_r_exio-1) * 163  + p_s_exio_single;  % index of the sector-RoWregion in prod persp. for exio
    p_r_s_eora_single = (p_r_eora_single - 1) * 26  + p_s_eora; % index of the sector-RoWcountry in prod persp. for eora
    p_r_s_eora_total = (p_r_eora_total - 1) * 26 + p_s_eora; % index of the sector-RoWregion in prod persp. for eora (vector)
    
    if p_r_exio < 45
    Ext_MF_Exio_res(k) = Ext_MF_Exio(p_r_s_exio);
    else
    if sum(Ext_MF_Eora(p_r_s_eora_total)) > 0
    Ext_MF_Exio_res(k) = Ext_MF_Exio(p_r_s_exio) * Ext_MF_Eora(p_r_s_eora_single) / sum(Ext_MF_Eora(p_r_s_eora_total));
    else    
    Ext_MF_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_CC_Exio_res(k) = Ext_CC_Exio(p_r_s_exio);
    else
    if sum(Ext_CC_Eora(p_r_s_eora_total)) > 0
    Ext_CC_Exio_res(k) = Ext_CC_Exio(p_r_s_exio) * Ext_CC_Eora(p_r_s_eora_single) / sum(Ext_CC_Eora(p_r_s_eora_total));
    else
    Ext_CC_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_HI_Exio_res(k) = Ext_HI_Exio(p_r_s_exio);
    else
    if sum(Ext_HI_Eora(p_r_s_eora_total)) > 0
    Ext_HI_Exio_res(k) = Ext_HI_Exio(p_r_s_exio) * Ext_HI_Eora(p_r_s_eora_single) / sum(Ext_HI_Eora(p_r_s_eora_total));
    else   
    Ext_HI_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_WS_Exio_res(k) = Ext_WS_Exio(p_r_s_exio);
    else
    if sum(Ext_WS_Eora(p_r_s_eora_total)) > 0
    Ext_WS_Exio_res(k) = Ext_WS_Exio(p_r_s_exio) * Ext_WS_Eora(p_r_s_eora_single) / sum(Ext_WS_Eora(p_r_s_eora_total));
    else 
    Ext_WS_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_LU_Exio_res(k) = Ext_LU_Exio(p_r_s_exio);
    else
    if sum(Ext_LU_Eora(p_r_s_eora_total)) > 0
    Ext_LU_Exio_res(k) = Ext_LU_Exio(p_r_s_exio) * Ext_LU_Eora(p_r_s_eora_single) / sum(Ext_LU_Eora(p_r_s_eora_total));
    else    
    Ext_LU_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_BWC_Exio_res(k) = Ext_BWC_Exio(p_r_s_exio);
    else
    if sum(Ext_BWC_Eora(p_r_s_eora_total)) > 0
    Ext_BWC_Exio_res(k) = Ext_BWC_Exio(p_r_s_exio) * Ext_BWC_Eora(p_r_s_eora_single) / sum(Ext_BWC_Eora(p_r_s_eora_total));
    else 
    Ext_BWC_Exio_res(k) = 0;
    end
    end
    
    
    if p_r_exio < 45
    Ext_LUA_Exio_res(k) = Ext_LUA_Exio(p_r_s_exio);
    else
    if sum(Ext_LUA_Eora(p_r_s_eora_total)) > 0
    Ext_LUA_Exio_res(k) = Ext_LUA_Exio(p_r_s_exio) * Ext_LUA_Eora(p_r_s_eora_single) / sum(Ext_LUA_Eora(p_r_s_eora_total));
    else 
    Ext_LUA_Exio_res(k) = 0;
    end
    end
    
    end
    end
    end
    end    




%
%%%%%%%% 4. Extensions of households %%%%%%%% 

p = 0;
q = 0;
for n = 0:48;
i = 1 + 7*n;
j = i + 5;
q = p + 1;
p = q + 5;
Ext_hh_MF_Exio_new(:,q:p) = Ext_hh_MF_Exio(:,i:j);
Ext_hh_CC_Exio_new(:,q:p) = Ext_hh_CC_Exio(:,i:j);
Ext_hh_HI_Exio_new(:,q:p) = Ext_hh_HI_Exio(:,i:j);
Ext_hh_WS_Exio_new(:,q:p) = Ext_hh_WS_Exio(:,i:j);
Ext_hh_LU_Exio_new(:,q:p) = Ext_hh_LU_Exio(:,i:j);
Ext_hh_BWC_Exio_new(:,q:p) = Ext_hh_BWC_Exio(:,i:j);
Ext_hh_LUA_Exio_new(:,q:p) = Ext_hh_LUA_Exio(:,i:j);
end
    

 k = 0;
    for p_r_exio = 1:49       % each RoW Region  
    p_r_eora_total = cell2mat(Exio_Eora_Region(p_r_exio))'; % corresponding index for each RoW Region in Eora 
    for p_r_eora_single = p_r_eora_total % corresponding index for each single RoW country in Eora 
    for p_c_both = 1:6;   
    k = k + 1;   
    p_r_c_exio =  (p_r_exio-1) * 6  + p_c_both;
    p_r_c_eora_single = (p_r_eora_single - 1) * 6  + p_c_both; 
    p_r_c_eora_total =  (p_r_eora_total - 1) * 6 + p_c_both;
    
    if p_r_exio < 45
    Ext_hh_MF_Exio_res(k) = Ext_hh_MF_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_MF_Eora(p_r_c_eora_total)) > 0
    Ext_hh_MF_Exio_res(k) = Ext_hh_MF_Exio_new(p_r_c_exio) * Ext_hh_MF_Eora(p_r_c_eora_single) / sum(Ext_hh_MF_Eora(p_r_c_eora_total));
    else
    Ext_hh_MF_Exio_res(k) = 0;
    end
    end
        
    if p_r_exio < 45
    Ext_hh_CC_Exio_res(k) = Ext_hh_CC_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_CC_Eora(p_r_c_eora_total)) > 0
    Ext_hh_CC_Exio_res(k) = Ext_hh_CC_Exio_new(p_r_c_exio) * Ext_hh_CC_Eora(p_r_c_eora_single) / sum(Ext_hh_CC_Eora(p_r_c_eora_total));
    else  
    Ext_hh_CC_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_hh_HI_Exio_res(k) = Ext_hh_HI_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_HI_Eora(p_r_c_eora_total)) > 0
    Ext_hh_HI_Exio_res(k) = Ext_hh_HI_Exio_new(p_r_c_exio) * Ext_hh_HI_Eora(p_r_c_eora_single) / sum(Ext_hh_HI_Eora(p_r_c_eora_total));
    else   
    Ext_hh_HI_Exio_res(k) = 0;
    end
    end    
    
    if p_r_exio < 45
    Ext_hh_WS_Exio_res(k) = Ext_hh_WS_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_WS_Eora(p_r_c_eora_total)) > 0
    Ext_hh_WS_Exio_res(k) = Ext_hh_WS_Exio_new(p_r_c_exio) * Ext_hh_WS_Eora(p_r_c_eora_single) / sum(Ext_hh_WS_Eora(p_r_c_eora_total));
    else 
    Ext_hh_WS_Exio_res(k) = 0;
    end
    end
    
    if p_r_exio < 45
    Ext_hh_LU_Exio_res(k) = Ext_hh_LU_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_LU_Eora(p_r_c_eora_total)) > 0
    Ext_hh_LU_Exio_res(k) = Ext_hh_LU_Exio_new(p_r_c_exio) * Ext_hh_LU_Eora(p_r_c_eora_single) / sum(Ext_hh_LU_Eora(p_r_c_eora_total));
    else 
    Ext_hh_LU_Exio_res(k) = 0;
    end
    end   
    
    if p_r_exio < 45
    Ext_hh_BWC_Exio_res(k) = Ext_hh_BWC_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_BWC_Eora(p_r_c_eora_total)) > 0
    Ext_hh_BWC_Exio_res(k) = Ext_hh_BWC_Exio_new(p_r_c_exio) * Ext_hh_BWC_Eora(p_r_c_eora_single) / sum(Ext_hh_BWC_Eora(p_r_c_eora_total));
    else 
    Ext_hh_BWC_Exio_res(k) = 0;
    end
    end   
    
    if p_r_exio < 45
    Ext_hh_LUA_Exio_res(k) = Ext_hh_LUA_Exio_new(p_r_c_exio);
    else
    if sum(Ext_hh_LUA_Eora(p_r_c_eora_total)) > 0
    Ext_hh_LUA_Exio_res(k) = Ext_hh_LUA_Exio_new(p_r_c_exio) * Ext_hh_LUA_Eora(p_r_c_eora_single) / sum(Ext_hh_LUA_Eora(p_r_c_eora_total));
    else
    Ext_hh_LUA_Exio_res(k) = 0;
    end
    end       
    end
    end
    end  





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2B) FOR WORKFORCE: TAKE IMPACT COEFFICIENTS DIRECTLY FROM EXIOBASE
% (BECAUSE NO WORKFORCE IS INDICATED BY EORA)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Workforce: total (1000 people FTE)
Ext_WF_Exio = sum(Q_Exio([10:15,22],:));
%Ext_hh_WF_Exio = sum(Q_hh_Exio([10:15,22],:)); %zero

d_WF_Exio = Ext_WF_Exio ./ TotalOut_Exio';  
d_WF_Exio(isinf(d_WF_Exio))=0 ; 
d_WF_Exio(isnan(d_WF_Exio))=0 ;  
d_WF_Exio = d_WF_Exio .* (d_WF_Exio>0); 

Countries_Exio_Eora_WF = [1:44,repmat(45,1,35),repmat(46,1,30),repmat(47,1,13),repmat(48,1,51),repmat(49,1,16)];
Sectors_Exio_Eora_WF = cell2mat(Eora_Exio_Sector)';

z = 0;
for n = Countries_Exio_Eora_WF;
for i = Sectors_Exio_Eora_WF;    
q = i + (163 * (n-1));
z= z+1;
index_reorder_Exio_Eora_WF(z)= q;
end
end

d_WF_Exio_res = d_WF_Exio(index_reorder_Exio_Eora_WF);




    
    
    
    
    
 
    
    
    
    
 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3) READ IN FAOSTAT DATA TO IMPROVE T AND Y MATRIX FOR BIOMASS SECTORS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Read in data from FAOSTAT  
datapath = ['Files/FAOSTAT/'];
FAO_Production_all = dlmread([datapath 'FAOSTAT_production_timeline.txt'],'\t',1,0); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

FAO_Matrix = zeros(21,351,50);

% reorder FAOSTAT data in 4D array: 
% 1D: year
% 2D: country no in FAOSTAT
% 3D: sector no in Exiobase
% 4D: Production amount from FAOSTAT
for f = 1:93384;
    index_year = FAO_Production_all(f,1)-1994; % year
    country_FAO = FAO_Production_all(f,2); % country no in FAOSTAT
    sector_FAO = FAO_Production_all(f,3); % sector no in Exiobase
    FAO_Matrix(index_year,country_FAO,sector_FAO) = FAO_Production_all(f,5);
end

% reorder countries according to Exio_Eora_res in 4D array: 
% 1D: years
% 2D: countries no in Exio_Eora_res
% 3D: sector no in Exioase
% 4D: Production amount from FAOSTAT
datapath = ['Files/FAOSTAT/'];
FAO_countrycode = dlmread([datapath 'FAOSTAT_countrycode.txt'],'\t',1,0); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

FAO_Matrix_final = zeros(21,189,50);

for c_Exio = 1:189
    c_FAO = FAO_countrycode(c_Exio);
    FAO_Matrix_final(:,c_Exio,:) = FAO_Matrix(:,c_FAO,:);
end

% Conversion of 5RoW regions Exiobase into 189 resolved regions (FAOSTAT)
countries = [1:44];
RoW_AsiaPacific = [45:79];
RoW_America = [80:111];
RoW_Europe = [112:123];
RoW_Africa = [124:173];
RoW_MiddleEast = [174:189];

k = 0;
for i = countries
    k = k+1;
Exio_res_Region(k,1) = num2cell(i);
end

Exio_res_Region(45,1) = num2cell(RoW_AsiaPacific',1);
Exio_res_Region(46,1) = num2cell(RoW_America',1);
Exio_res_Region(47,1) = num2cell(RoW_Europe',1);
Exio_res_Region(48,1) = num2cell(RoW_Africa',1);
Exio_res_Region(49,1) = num2cell(RoW_MiddleEast',1);


% Calculate total output of the resolved MRIO database
TotalOut_Exio_res = sum(T_Exio_res,2) + sum(Y_Exio_res,2);

% Take over resolved values; Values for biomass sector will be overwritten
TotalOut_Exio_res_FAO = TotalOut_Exio_res; 

% Resolve biomass sectors of Exio by FAO (except for wood products, the
% sector no is the same for the resolved database)
for r_Exio = 45:49;
    r_FAO_total = cell2mat(Exio_res_Region(r_Exio))';
for r_FAO_single = r_FAO_total;
for s_both = [1:15,19,35:40,42,45,49];   
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_FAO = s_both + 163 * (r_FAO_single-1);
    if FAO_Matrix_final(k_year,r_FAO_single,s_both) > 0;
    TotalOut_Exio_res_FAO(rs_Exio_FAO,1) = TotalOut_Exio(rs_Exio) * FAO_Matrix_final(k_year,r_FAO_single,s_both)/sum(FAO_Matrix_final(k_year,r_FAO_total,s_both));
    end
end
end
end

% wood
for r_Exio = 45:49;
    r_FAO_total = cell2mat(Exio_res_Region(r_Exio))';
for r_FAO_single = r_FAO_total;    
    rs_Exio = 50 + 163 * (r_Exio-1);
    rs_Exio_FAO = 49 + 163 * (r_FAO_single-1);
    if FAO_Matrix_final(k_year,r_FAO_single,50) > 0;
    TotalOut_Exio_res_FAO(rs_Exio_FAO,1) = TotalOut_Exio(rs_Exio) * FAO_Matrix_final(k_year,r_FAO_single,50)/sum(FAO_Matrix_final(k_year,r_FAO_total,50));
    end
end
end

% forestry
datapath = ['Files/FAOSTAT/'];
forestry = dlmread([datapath 'FAOSTAT_forestry.txt'],'\t',1,1); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

for r_Exio = 45:49;
    r_FAO_total = cell2mat(Exio_res_Region(r_Exio))';
for r_FAO_single = r_FAO_total;
for s_both = 18;
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_FAO = s_both + 163 * (r_FAO_single-1);
    if forestry(r_FAO_single,k_year) > 0;
    TotalOut_Exio_res_FAO(rs_Exio_FAO,1) = TotalOut_Exio(rs_Exio) * forestry(r_FAO_single,k_year)/sum(forestry(r_FAO_total,k_year));
    end
end
end
end


for i = 1:30807
    if TotalOut_Exio_res(i) > 0
    factor_TotalOut(i) = TotalOut_Exio_res_FAO(i) / TotalOut_Exio_res(i);
    else
    factor_TotalOut(i) = 1;
    end
end

T_Exio_res_FAO = factor_TotalOut' .* T_Exio_res;
Y_Exio_res_FAO = factor_TotalOut' .* Y_Exio_res;

% check if the sum is the same
%sum(sum(Y_Exio_res))/ sum(sum(Y_Exio_res_FAO))
%sum(sum(T_Exio_res))/sum(sum(T_Exio_res_FAO))







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 4) READ IN DATA FROM PFISTER AND BAYER (2014) TO IMPROVE WATER STRESS
%    DATA FOR CROPS SECTORS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%% 1. Water stress data --> Adapt Ext_WS %%%%%%%%
datapath = ['Files/Pfister/'];
Pfis_WS = dlmread([datapath 'WS_Pfister.txt'],'\t',1,1); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

Ext_WS_Exio_res_Pfis = Ext_WS_Exio_res;

% Resolve crops sectors
for r_Exio = 45:49;
    r_Pfis_total = cell2mat(Exio_res_Region(r_Exio))';
for r_Pfis_single = r_Pfis_total;
    for s_both = 1:8;    
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_Pfis = s_both + 163 * (r_Pfis_single-1);
        if Pfis_WS(r_Pfis_single,s_both) > 0;
        Ext_WS_Exio_res_Pfis(rs_Exio_Pfis) = Ext_WS_Exio(rs_Exio) * Pfis_WS(r_Pfis_single,s_both)/sum(Pfis_WS(r_Pfis_total,s_both));
        end
    end
end
end


%%%%%%%% 2. Blue water consumption --> Adapt Ext_BWC %%%%%%%%
datapath = ['Files/Pfister/'];
Pfis_BWC = dlmread([datapath 'BWC_Pfister.txt'],'\t',1,1); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

Ext_BWC_Exio_res_Pfis = Ext_BWC_Exio_res;

% Resolve crops sectors
for r_Exio = 45:49;
    r_Pfis_total = cell2mat(Exio_res_Region(r_Exio))';
for r_Pfis_single = r_Pfis_total;
for s_both = 1:8;    
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_Pfis = s_both + 163 * (r_Pfis_single-1);
        if Pfis_BWC(r_Pfis_single,s_both) > 0;
        Ext_BWC_Exio_res_Pfis(rs_Exio_Pfis) = Ext_BWC_Exio(rs_Exio) * Pfis_BWC(r_Pfis_single,s_both)/sum(Pfis_BWC(r_Pfis_total,s_both));
        end
end
end
end








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 5) READ IN DATA FROM PFISTER ET AL TO IMPROVE LAND-USE RELATED BIODIVERSITY LOSS DATA 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%% 1. Land-use related biodiversity loss data --> Adapt Ext_LU %%%%%%%%

datapath = ['Files/Pfister/'];
BDloss_all = dlmread([datapath 'LU_BDloss_Pfister.txt'],'\t',1,0); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

BDloss_Matrix = zeros(21,189,18);
% reorder it in 4D array: 
% 1D: years
% 2D: countries (exiobase resolved no)
% 3D: sectors (exiobase resolved no)

for f = 1:34574;
    BDloss_year = BDloss_all(f,1)-1994;
    BDloss_country = BDloss_all(f,2);
    BDloss_sector = BDloss_all(f,3); 
    BDloss_Matrix(BDloss_year,BDloss_country,BDloss_sector) = BDloss_all(f,4);
end

Ext_LU_Exio_res_Pfis = Ext_LU_Exio_res;

k_year = year - 1994;

% Resolve crops, pasture and forestry sectors
for r_Exio = 45:49;
    r_FAO_total = cell2mat(Exio_res_Region(r_Exio))';
for r_FAO_single = r_FAO_total;
for s_both = [1:9,14,18];    %crops,cattle,forestry
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_FAO = s_both + 163 * (r_FAO_single-1);
    if BDloss_Matrix(k_year,r_FAO_single,s_both) > 0;
    Ext_LU_Exio_res_Pfis(rs_Exio_FAO) = Ext_LU_Exio(rs_Exio) * BDloss_Matrix(k_year,r_FAO_single,s_both)/sum(BDloss_Matrix(k_year,r_FAO_total,s_both));
    end    
end
end
end


%%%%%%%% 2. Land use area --> Adapt Ext_LUA %%%%%%%%

datapath = ['Files/Pfister/'];
LUA_all = dlmread([datapath 'LUA_Pfister_FAOSTAT.txt'],'\t',1,0); % Q = environmental and social extensions (rows) for 7987 sector-region combinations (columns)

LUA_Matrix = zeros(21,189,18);
% reorder it in 4D array: 
% 1D: years
% 2D: countries (exiobase resolved no)
% 3D: sectors (exiobase resolved no)

for f = 1:42147;
    LUA_year = LUA_all(f,1)-1994;
    LUA_country = LUA_all(f,2);
    LUA_sector = LUA_all(f,3); 
    LUA_Matrix(LUA_year,LUA_country,LUA_sector) = LUA_all(f,4);
end

Ext_LUA_Exio_res_Pfis = Ext_LUA_Exio_res;

k_year = year - 1994;

% Resolve crops, pasture and forestry sectors
for r_Exio = 45:49;
    r_FAO_total = cell2mat(Exio_res_Region(r_Exio))';
for r_FAO_single = r_FAO_total;
for s_both = [1:9,14,18];    %crops,cattle,forestry
    rs_Exio = s_both + 163 * (r_Exio-1);
    rs_Exio_FAO = s_both + 163 * (r_FAO_single-1);
    if LUA_Matrix(k_year,r_FAO_single,s_both) > 0;
    Ext_LUA_Exio_res_Pfis(rs_Exio_FAO) = Ext_LUA_Exio(rs_Exio) * LUA_Matrix(k_year,r_FAO_single,s_both)/sum(LUA_Matrix(k_year,r_FAO_total,s_both));
    end    
end
end
end







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 6A) DERIVE FINAL MATRICES FOR RESOLVED DATABASE AND SAVE DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Derive resolved coefficient matrix A
TotalOut_Exio_res_FAO = TotalOut_Exio_res_FAO .* (TotalOut_Exio_res_FAO>1); % set small and negative values to zero;
A_Exio_res_FAO = T_Exio_res_FAO ./ repmat(TotalOut_Exio_res_FAO',length(TotalOut_Exio_res_FAO'),1); % This is identical to T * diag(1./TotalIn) and to A = T * inv(diag(TotalIn)) but much faster!
A_Exio_res_FAO(isinf(A_Exio_res_FAO))=0 ;  % Set inf in matrix A to zero
A_Exio_res_FAO(isnan(A_Exio_res_FAO))=0 ;  % Set nan in matrix A to zero

% Derive resolved Leontief Inverse L
%I_Exio_res_FAO = eye(size(A_Exio_res_FAO));
%L_Exio_res_FAO = inv(I_Exio_res_FAO-A_Exio_res_FAO);

% Compile all variables
A_RMRIO = A_Exio_res_FAO;
%L_RMRIO = L_Exio_res_FAO;
%T_RMRIO = T_Exio_res_FAO;
Y_RMRIO = Y_Exio_res_FAO;
TotalOut_RMRIO = TotalOut_Exio_res_FAO;

% Workforce extension
Ext_WF_Exio_res = d_WF_Exio_res .* TotalOut_RMRIO';

% DERIVE NEW VALUE ADDED FOR BALANCING
colsum_T = sum(T_Exio_res_FAO)';
Ext_VA_Exio_res(1,:) = TotalOut_Exio_res_FAO' - colsum_T';

% Compile extensions for Economy
Ext_RMRIO(1,:) = Ext_MF_Exio_res;
Ext_RMRIO(2,:) = Ext_CC_Exio_res;
Ext_RMRIO(3,:) = Ext_HI_Exio_res;
Ext_RMRIO(4,:) = Ext_WS_Exio_res_Pfis;
Ext_RMRIO(5,:) = Ext_LU_Exio_res_Pfis;
Ext_RMRIO(6,:) = Ext_VA_Exio_res;
Ext_RMRIO(7,:) = Ext_WF_Exio_res;
Ext_RMRIO(8,:) = Ext_BWC_Exio_res_Pfis;
Ext_RMRIO(9,:) = Ext_LUA_Exio_res_Pfis;

% Compile extensions for households
Ext_hh_RMRIO(1,:) = Ext_hh_MF_Exio_res;
Ext_hh_RMRIO(2,:) = Ext_hh_CC_Exio_res;
Ext_hh_RMRIO(3,:) = Ext_hh_HI_Exio_res;
Ext_hh_RMRIO(4,:) = Ext_hh_WS_Exio_res;
Ext_hh_RMRIO(5,:) = Ext_hh_LU_Exio_res;
Ext_hh_RMRIO(6,:) = 0;
Ext_hh_RMRIO(7,:) = 0;
Ext_hh_RMRIO(8,:) = Ext_hh_BWC_Exio_res;
Ext_hh_RMRIO(9,:) = Ext_hh_LUA_Exio_res;


% Save data
datapath = ['DATA_RMRIO/'];
mkdir([datapath 'Year_' num2str(year) '_RMRIO/']);

datapath = ['DATA_RMRIO/Year_' num2str(year) '_RMRIO/'];
%save([datapath 'T_RMRIO'],'T_RMRIO');
save([datapath 'A_RMRIO'],'A_RMRIO');
%save([datapath 'L_RMRIO'],'L_RMRIO');
save([datapath 'Y_RMRIO'],'Y_RMRIO');
save([datapath 'Ext_RMRIO'],'Ext_RMRIO');
save([datapath 'Ext_hh_RMRIO'],'Ext_hh_RMRIO');
save([datapath 'TotalOut_RMRIO'],'TotalOut_RMRIO');



end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 6B) DERIVE AND SAVE THE NEW LABELS OF THE RESOLVED DATABASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sectors_row_new = cell2mat(Eora_Exio_Sector)';
regions_row_new = cell2mat(Exio_Eora_Region)';
Labels_Sectors_RMRIO = Labels_Sectors_Exio(sectors_row_new);
Labels_Countries_RMRIO = Labels_Regions_Eora(regions_row_new);
%Labels_FDcat_Exio_res = Labels_FDcat_Exio(1:6);

for n = 1:189
    i = 1 + 163 * (n-1);
    j = i + 162;
    Labels_Production_RMRIO(i:j,1)= Labels_Countries_RMRIO(n);
end
for n = 1:189
    i = 1 + 163 * (n-1);
    j = i + 162;
    Labels_Production_RMRIO(i:j,2)= Labels_Sectors_RMRIO(:);
end

for n = 1:189
    i = 1 + 6 * (n-1);
    j = i + 5;
    Labels_FinalDemand_RMRIO(i:j,1)= Labels_Countries_RMRIO(n);
end
for n = 1:189
    i = 1 + 6 * (n-1);
    j = i + 5;
    Labels_FinalDemand_RMRIO(i:j,2)= Labels_FDcat_Exio(1:6);
end

% Labels for extensions
Labels_Extensions_RMRIO(1,1) = {'Material footprint'};
Labels_Extensions_RMRIO(2,1) = {'Climate change impacts'};
Labels_Extensions_RMRIO(3,1) = {'PM health impacts'};
Labels_Extensions_RMRIO(4,1) = {'Water stress'};
Labels_Extensions_RMRIO(5,1) = {'Land-use related biodiversity loss'};
Labels_Extensions_RMRIO(6,1) = {'Value added'};
Labels_Extensions_RMRIO(7,1) = {'Workforce'};
Labels_Extensions_RMRIO(8,1) = {'Blue water consumption'};
Labels_Extensions_RMRIO(9,1) = {'Land-use area'};

Labels_Extensions_RMRIO(1,2) = {'kt'};
Labels_Extensions_RMRIO(2,2) = {'kg CO2eq'};
Labels_Extensions_RMRIO(3,2) = {'DALYs'};
Labels_Extensions_RMRIO(4,2) = {'Mio m3 H2Oeq'};
Labels_Extensions_RMRIO(5,2) = {'global PDF'};
Labels_Extensions_RMRIO(6,2) = {'Mio Euro'};
Labels_Extensions_RMRIO(7,2) = {'1000 FTE'};
Labels_Extensions_RMRIO(8,2) = {'Mio m3'};
Labels_Extensions_RMRIO(9,2) = {'km2'};

% Save new labels
datapath = ['DATA_RMRIO/'];
mkdir([datapath 'Labels_RMRIO/']);

datapath = ['DATA_RMRIO/Labels_RMRIO/'];
save([datapath 'Labels_Countries_RMRIO'],'Labels_Countries_RMRIO');
save([datapath 'Labels_Sectors_RMRIO'],'Labels_Sectors_RMRIO');
save([datapath 'Labels_Production_RMRIO'],'Labels_Production_RMRIO');
save([datapath 'Labels_FinalDemand_RMRIO'],'Labels_FinalDemand_RMRIO');
save([datapath 'Labels_Extensions_RMRIO'],'Labels_Extensions_RMRIO');
